summaryrefslogtreecommitdiff
path: root/gtk2_ardour/editor_mouse.cc
diff options
context:
space:
mode:
authornick_m <mainsbridge@gmail.com>2015-01-15 00:06:16 +1100
committernick_m <mainsbridge@gmail.com>2015-01-15 00:06:16 +1100
commit44f2f53cdef43bc7ca3abe60bb138baa2565db0c (patch)
tree312b16836225447ba152f89aa9ccd2703680eafa /gtk2_ardour/editor_mouse.cc
parente1f8112f81c655684ec18b881528df9208c00af0 (diff)
A test for less brutall deselection on mouse mode change.
Mostly stops toggling smart mode from doing anything to the selection.
Diffstat (limited to 'gtk2_ardour/editor_mouse.cc')
-rw-r--r--gtk2_ardour/editor_mouse.cc12
1 files changed, 7 insertions, 5 deletions
diff --git a/gtk2_ardour/editor_mouse.cc b/gtk2_ardour/editor_mouse.cc
index de71c4a77f..b8da2ee80c 100644
--- a/gtk2_ardour/editor_mouse.cc
+++ b/gtk2_ardour/editor_mouse.cc
@@ -342,14 +342,16 @@ Editor::update_time_selection_display ()
selection->ClearMidiNoteSelection (); /* EMIT SIGNAL */
break;
case MouseDraw:
- /* Clear top level objects, but not time or tracks, since that
- woulddestroy the range selection rectangle, which we need to stick
+ /* Clear regions, but not time or tracks, since that
+ would destroy the range selection rectangle, which we need to stick
around for AutomationRangeDrag. */
- selection->clear_objects ();
+ selection->clear_regions ();
break;
default:
- /* Clear everything. */
- selection->clear_objects ();
+ /* This handles internal edit.
+ Clear everything except points and notes.
+ */
+ selection->clear_regions();
selection->clear_time ();
selection->clear_tracks ();
break;